@@ -77,7 +77,7 @@ def find_validation(validation):
     return '{}/{}.yaml'.format(constants.DEFAULT_VALIDATIONS_PATH, validation)
 
 
-def run_validation(validation, identity_file):
+def run_validation(validation, identity_file, plan):
     ctx = context.ctx()
     return processutils.execute(
         '/usr/bin/sudo', '-u', 'validations',
@@ -87,17 +87,11 @@ def run_validation(validation, identity_file):
         'OS_TENANT_NAME={}'.format(ctx.project_name),
         '/usr/bin/run-validation',
         find_validation(validation),
-        identity_file
+        identity_file,
+        plan
     )
 
 
-def create_ssh_keypair(key_path):
-    """Create SSH keypair"""
-    LOG.debug('Creating SSH keypair at %s', key_path)
-    processutils.execute('/usr/bin/ssh-keygen', '-t', 'rsa', '-N', '',
-                         '-f', key_path, '-C', 'tripleo-validations')
-
-
 def write_identity_file(key):
     """Write the SSH private key to disk"""
     fd, path = tempfile.mkstemp(prefix='validations_identity_')
@@ -110,6 +104,6 @@ def write_identity_file(key):
 
 
 def cleanup_identity_file(path):
-    """Write the SSH private key to disk"""
+    """Remove the SSH private key from disk"""
     LOG.debug('Cleaning up identity file at %s', path)
     processutils.execute('/usr/bin/sudo', '/usr/bin/rm', '-f', path)
